Main Interface — sfrout 0.0.17 documentation

Here you can find exact details regarding user interfaces.

# Main Interface

This is the entry point ot the application.

main.run(*, domain: str, reports_path: str, reports_list: list[dict[str, str]] = [], summary_filepath: str = '', log_path: str = '', report: str = '', path: str = '', threads: int = 0, stdout_loglevel: str = 'WARNING', file_loglevel: str = 'INFO', verbose: bool = False) → None

  Main function of the program.

  Parameters:

    - domain (str) – SalesForce domain of your organization -> “https://corp.my.salesforce.com/”

    - reports_path (str) – Path to reports.csv file, template -> Template

    - reports_list (list[dict[str, str]], optional) – List of the reports as dictionaries -> `[{'name': 'RaportName', 'id': '00O1V00000999GHES', 'path': WindowsPath('C:/downloads')}]` , defaults to []

    - summary_filepath (str, optional) – File path to summary report -> `C:/downloads/summary.csv` , defaults to “”

    - log_path (str, optional) – Path to log file -> `C:/downloads/logs/` , defaults to “”

    - report (str, optional) – Single report mode -> `RaportName,00O1V00000999GHES,C:/downloads` , defaults to “”

    - path (str, optional) – Save location path override -> `C:/new_downloads` , defaults to “”

    - threads (int, optional) – Number of threads to use, defaults to 0

    - stdout_loglevel (str, optional) – Log level for stdout logging -> `['critical'|'error'|'warn'|'warning'|'info'|'debug']` , defaults to WARNING

    - file_loglevel (str, optional) – Log level for file logging -> `['critical'|'error'|'warn'|'warning'|'info'|'debug']` , defaults to INFO

    - verbose (bool, optional) – flag, stdout logging if `True` , Progress Bar if `False` , defaults to False

  Usage:

      import sfrout
      sfrout.run(domain="https://corp.my.salesforce.com/", reports_path="C:/path/to/reports.csv")

## cli

SFrout is a scalable, asynchronous SalesForce report downloader for SAML/SSO clients. The app allows you to download reports based on their ID using your personal SFDC account. Supports asynchronous requests, threaded processing of the files, logging to rotating file and stdout, produces summary report for the session.

Usage:

    $ sfrout "https://corp.my.salesforce.com/" "C:\path\to\reports.csv"

    cli [OPTIONS] DOMAIN [REPORTS_PATH]

Options

-s, --summary_filepath <summary_filepath>

  Path to the summary report -> c:/summary_report.csv

-l, --log_path <log_path>

  Path to the log file -> c:/log

-r, --report <report>

  Run single report -> “name,id,path,optional_report_params”

-p, --path <path>

  Override save location of the reports

-t, --threads <threads>

  Number of threads to spawn

  Default:

    `0`

-ls, --stdout_loglevel <stdout_loglevel>

  STDOUT logging level -> [DEBUG | INFO | WARN |WARNING | ERROR | CRITICAL]

  Default:

    `WARNING`

-lf, --file_loglevel <file_loglevel>

  File logging level -> [DEBUG | INFO | WARN| WARNING | ERROR | CRITICAL]

  Default:

    `INFO`

-v, --verbose

  Turn off progress bar

  Default:

    `False`

Arguments

DOMAIN

  Required argument

REPORTS_PATH

  Optional argument